@@ -11,7 +11,7 @@ import logging
 from time import time
 from functools import wraps
 from datetime import datetime
-from typing import Tuple, Callable, Union
+from typing import Tuple, Callable, Union, Dict, List
 from .utils import get_params, parse_time, random_string
 from .backends import Backend
 
@@ -38,7 +38,7 @@ def cache(function):
 class Cache:
     def __init__(
         self,
-        cache_path: str = "{cache_dir}/{function_name}/{_hash}.pkl",
+        cache_path: Union[str, Tuple[str], List[str], Dict[str, str]] = "{cache_dir}/{function_name}/{_hash}.pkl",
         args_to_ignore: Tuple[str] = (),
         cache_dir: str = None,
         validity_duration: Union[int, str] = -1,
@@ -63,7 +63,7 @@ class Cache:
 
         Arguments
         ---------
-        cache_path: str = "{cache_dir}/{function_name}/{_hash}.pkl",
+        cache_path: Union[str, Tuple[str], List[str], Dict[str, str]] = "{cache_dir}/{function_name}/{_hash}.pkl",
             Where to save the caches.
             It's a string format and the available variables are
             `cache_dir` the directory specified in the other argument.
@@ -398,8 +398,6 @@ class Cache:
                 self.decorated_function.__code__.co_filename,
                 self.decorated_function.__code__.co_firstlineno
             ),
-            # TODO re-insert
-            #"parameter":get_params(self.function_info, args, kwargs),
             "args_to_ignore":self.function_info["args_to_ignore"],
             "source":self.function_info.get("source", None),
 
@@ -408,6 +406,21 @@ class Cache:
             "backend_metadata":backend_metadata,
         }
 
+        params = {}
+        for key, val in get_params(self.function_info, args, kwargs).items():
+            if key in self.args_to_ignore:
+                continue
+
+            try:
+                # Check if it's json serializable
+                json.dumps(val)
+                params[key] = val
+            except:
+                pass
+
+
+        metadata["parameters"] = params
+
         metadata_path = self._get_metadata_path(path)
         self.logger.info("Saving the cache meta-data at %s", metadata_path)
         with open(metadata_path, "w") as f:
